@@ -3,6 +3,7 @@ from .dirdialog_multiselect import DirectoryDialogMultiSelect
 from .mpl_navigation_toolbar_icons import (
     NavigationToolbarIndent,
     NavigationToolbarEDelta,
-    NavigationToolbarQMap
+    NavigationToolbarQMap,
+    NavigationToolbarPreproc
     )
 from .wait_cursor import ShowWaitCursor, show_wait_cursor
